@@ -1,4 +1,4 @@
-# Copyright © 2012-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2019 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -39,7 +39,7 @@ from lib import paths as pathmod
 from lib import tags
 from lib import terminal
 
-__version__ = '0.25.7'
+__version__ = '0.25.8'
 
 def initialize_terminal():
     if sys.stdout.isatty():
@@ -93,11 +93,10 @@ def check_deb(filename, *, options):
             real_root = os.path.join(tmpdir, '')
         else:
             real_root = os.path.join(tmpdir, 's', '')
-            with open(os.devnull) as bitbucket:
-                ipc.check_call(
-                    ['dpkg-source', '--no-copy', '--no-check', '-x', filename, real_root],
-                    stdout=bitbucket  # dpkg-source would be noisy without this...
-                )
+            ipc.check_call(
+                ['dpkg-source', '--no-copy', '--no-check', '-x', filename, real_root],
+                stdout=ipc.DEVNULL  # dpkg-source would be noisy without this...
+            )
         options = copy_options(options,
             ignore_tags=ignore_tags,
             fake_root=(real_root, os.path.join(filename, ''))
@@ -161,7 +160,7 @@ class VersionAction(argparse.Action):
             option_strings=option_strings,
             dest=dest,
             nargs=0,
-            help="show program's version information and exit"
+            help='show version information and exit'
         )
 
     @staticmethod
