@@ -1,4 +1,4 @@
-# Copyright © 2012-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -55,7 +55,7 @@ header_fields = _read_header_fields()
 # header and message parsing
 # ==========================
 
-is_valid_field_name = re.compile(r'^[\x21-\x39\x3b-\x7e]+$').match
+is_valid_field_name = re.compile(r'^[\x21-\x39\x3B-\x7E]+$').match
 # https://tools.ietf.org/html/rfc5322#section-3.6.8
 
 def parse_header(s):
@@ -72,7 +72,7 @@ def parse_header(s):
             yield line
 
 search_for_conflict_marker = re.compile(r'^#-#-#-#-#  .+  #-#-#-#-#$', re.MULTILINE).search
-# http://git.savannah.gnu.org/cgit/gettext.git/tree/gettext-tools/src/msgl-cat.c?id=v0.18.3#n590
+# https://git.savannah.gnu.org/cgit/gettext.git/tree/gettext-tools/src/msgl-cat.c?id=v0.18.3#n590
 # https://www.gnu.org/software/gettext/manual/html_node/Creating-Compendia.html#Creating-Compendia
 
 # ============
