@@ -1,4 +1,4 @@
-# Copyright © 2013-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2013-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -40,7 +40,7 @@ big_endian_magic = little_endian_magic[::-1]
 class SyntaxError(Exception):  # pylint: disable=redefined-builtin
     pass
 
-class Parser(object):
+class Parser():
 
     def __init__(self, path, *, encoding=None, check_for_duplicates=False, klass=None):
         self._encoding = encoding
@@ -49,8 +49,8 @@ class Parser(object):
         with open(path, 'rb') as file:
             contents = file.read()
         view = memoryview(contents)
+        view = view.cast('c')
         if len(view) > 0:
-            view = view.cast('c')
             assert isinstance(view[0], bytes)
         self._view = view
         if klass is None:
@@ -143,15 +143,13 @@ class Parser(object):
                         pass
             if encoding is None:
                 encoding = 'ASCII'
-            else:
-                if not encodings.is_ascii_compatible_encoding(encoding):
-                    encoding = 'ASCII'
+            elif not encodings.is_ascii_compatible_encoding(encoding):
+                encoding = 'ASCII'
             self._encoding = encoding
-        else:
-            if msgids == self._last_msgid:
-                raise SyntaxError('duplicate message definition')
-            elif msgid < self._last_msgid:
-                raise SyntaxError('messages are not sorted')
+        elif msgids == self._last_msgid:
+            raise SyntaxError('duplicate message definition')
+        elif msgid < self._last_msgid:
+            raise SyntaxError('messages are not sorted')
         self._last_msgid = msgid  # pylint: disable=attribute-defined-outside-init
         assert encoding is not None
         msgid, *msgctxt = msgid.split(b'\x04', 1)
