@@ -152,21 +152,21 @@ class PrecisionRangeError(Error):
     message = 'precision too large'
 
 
-class VariableWidth(object):
+class VariableWidth():
 
     type = 'int'
 
     def __init__(self, parent):
         self.parent = parent
 
-class VariablePrecision(object):
+class VariablePrecision():
 
     type = 'int'
 
     def __init__(self, parent):
         self.parent = parent
 
-class FormatString(object):
+class FormatString():
 
     def __init__(self, s):
         self._items = items = []
@@ -214,14 +214,13 @@ class FormatString(object):
             else:
                 n = self._next_arg_index
                 self._next_arg_index += 1
+        elif self._next_arg_index is None:
+            pass
+        elif self._next_arg_index == 1:
+            assert not self._argument_map
+            self._next_arg_index = None
         else:
-            if self._next_arg_index is None:
-                pass
-            elif self._next_arg_index == 1:
-                assert not self._argument_map
-                self._next_arg_index = None
-            else:
-                raise IndexError
+            raise IndexError
         if n > NL_ARGMAX:
             raise OverflowError(n)
         self._argument_map[n] += [value]
@@ -268,7 +267,7 @@ class FormatString(object):
     def __len__(self):
         return len(self._items)
 
-class Conversion(object):
+class Conversion():
 
     type = None
     integer = None
@@ -306,7 +305,7 @@ class Conversion(object):
                     '%' + length + conversion,
                     '%' + plength + conversion
                 )
-            tp = i.int_types.get(plength or '')
+            tp = i.int_types.get(plength or '')  # pylint: disable=no-member
             assert tp is not None
             tp = tp[conversion in i.uint_cvt]
             if conversion == 'n':
