@@ -1,4 +1,4 @@
-# Copyright © 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2013-2019 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -20,6 +20,7 @@
 
 from nose.tools import (
     assert_equal,
+    assert_raises,
 )
 
 import lib.iconv as M
@@ -47,4 +48,9 @@ class test_tcvn(_test):
     b = b'Do b\xB9ch kim r\xCAt qu\xFD, s\xCF \xAE\xD3 l\xBEp v\xAB x\xAD\xACng'
     e = 'TCVN-5712'
 
+def test_incomplete_char():
+    b = u'Ę'.encode('UTF-8')[:1]
+    with assert_raises(UnicodeDecodeError):
+        M.decode(b, 'UTF-8')
+
 # vim:ts=4 sts=4 sw=4 et
